# coding: utf-8

"""
    EPIC API

    REST API for interacting with EPIC (https://epic.zenotech.com) services. <br />                             Please note this API is in BETA and does not yet contain                             all EPIC functionality.  # noqa: E501

    The version of the OpenAPI document: v2
    Contact: support@zenotech.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from epiccore.configuration import Configuration


class JobAuthStatus(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'required': 'bool',
        'state': 'str',
        'job': 'JobSummary',
        'user_profile': 'UserName',
        'permissions': 'str'
    }

    attribute_map = {
        'required': 'required',
        'state': 'state',
        'job': 'job',
        'user_profile': 'user_profile',
        'permissions': 'permissions'
    }

    def __init__(self, required=None, state=None, job=None, user_profile=None, permissions=None, local_vars_configuration=None):  # noqa: E501
        """JobAuthStatus - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._required = None
        self._state = None
        self._job = None
        self._user_profile = None
        self._permissions = None
        self.discriminator = None

        if required is not None:
            self.required = required
        if state is not None:
            self.state = state
        if job is not None:
            self.job = job
        if user_profile is not None:
            self.user_profile = user_profile
        if permissions is not None:
            self.permissions = permissions

    @property
    def required(self):
        """Gets the required of this JobAuthStatus.  # noqa: E501

        Is authorisation required for this job?  # noqa: E501

        :return: The required of this JobAuthStatus.  # noqa: E501
        :rtype: bool
        """
        return self._required

    @required.setter
    def required(self, required):
        """Sets the required of this JobAuthStatus.

        Is authorisation required for this job?  # noqa: E501

        :param required: The required of this JobAuthStatus.  # noqa: E501
        :type required: bool
        """

        self._required = required

    @property
    def state(self):
        """Gets the state of this JobAuthStatus.  # noqa: E501


        :return: The state of this JobAuthStatus.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this JobAuthStatus.


        :param state: The state of this JobAuthStatus.  # noqa: E501
        :type state: str
        """
        allowed_values = ["PENDING", "AUTHORISED", "REJECTED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and state not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `state` ({0}), must be one of {1}"  # noqa: E501
                .format(state, allowed_values)
            )

        self._state = state

    @property
    def job(self):
        """Gets the job of this JobAuthStatus.  # noqa: E501


        :return: The job of this JobAuthStatus.  # noqa: E501
        :rtype: JobSummary
        """
        return self._job

    @job.setter
    def job(self, job):
        """Sets the job of this JobAuthStatus.


        :param job: The job of this JobAuthStatus.  # noqa: E501
        :type job: JobSummary
        """

        self._job = job

    @property
    def user_profile(self):
        """Gets the user_profile of this JobAuthStatus.  # noqa: E501


        :return: The user_profile of this JobAuthStatus.  # noqa: E501
        :rtype: UserName
        """
        return self._user_profile

    @user_profile.setter
    def user_profile(self, user_profile):
        """Sets the user_profile of this JobAuthStatus.


        :param user_profile: The user_profile of this JobAuthStatus.  # noqa: E501
        :type user_profile: UserName
        """

        self._user_profile = user_profile

    @property
    def permissions(self):
        """Gets the permissions of this JobAuthStatus.  # noqa: E501


        :return: The permissions of this JobAuthStatus.  # noqa: E501
        :rtype: str
        """
        return self._permissions

    @permissions.setter
    def permissions(self, permissions):
        """Sets the permissions of this JobAuthStatus.


        :param permissions: The permissions of this JobAuthStatus.  # noqa: E501
        :type permissions: str
        """

        self._permissions = permissions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobAuthStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, JobAuthStatus):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    EPIC API

    REST API for interacting with EPIC (https://epic.zenotech.com) services. <br />                             Please note this API is in BETA and does not yet contain                             all EPIC functionality.  # noqa: E501

    The version of the OpenAPI document: v2
    Contact: support@zenotech.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from epiccore.configuration import Configuration


class JobTaskSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'reference': 'str',
        'partitions': 'int',
        'runtime': 'int',
        'task_distribution': 'str',
        'hyperthreading': 'bool'
    }

    attribute_map = {
        'reference': 'reference',
        'partitions': 'partitions',
        'runtime': 'runtime',
        'task_distribution': 'task_distribution',
        'hyperthreading': 'hyperthreading'
    }

    def __init__(self, reference=None, partitions=None, runtime=None, task_distribution=None, hyperthreading=True, local_vars_configuration=None):  # noqa: E501
        """JobTaskSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._reference = None
        self._partitions = None
        self._runtime = None
        self._task_distribution = None
        self._hyperthreading = None
        self.discriminator = None

        self.reference = reference
        self.partitions = partitions
        self.runtime = runtime
        self.task_distribution = task_distribution
        if hyperthreading is not None:
            self.hyperthreading = hyperthreading

    @property
    def reference(self):
        """Gets the reference of this JobTaskSpec.  # noqa: E501

        A reference to help you identify this task  # noqa: E501

        :return: The reference of this JobTaskSpec.  # noqa: E501
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this JobTaskSpec.

        A reference to help you identify this task  # noqa: E501

        :param reference: The reference of this JobTaskSpec.  # noqa: E501
        :type reference: str
        """
        if self.local_vars_configuration.client_side_validation and reference is None:  # noqa: E501
            raise ValueError("Invalid value for `reference`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                reference is not None and len(reference) > 25):
            raise ValueError("Invalid value for `reference`, length must be less than or equal to `25`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                reference is not None and len(reference) < 1):
            raise ValueError("Invalid value for `reference`, length must be greater than or equal to `1`")  # noqa: E501

        self._reference = reference

    @property
    def partitions(self):
        """Gets the partitions of this JobTaskSpec.  # noqa: E501

        How many partitions/tasks will this task be submitted as.  # noqa: E501

        :return: The partitions of this JobTaskSpec.  # noqa: E501
        :rtype: int
        """
        return self._partitions

    @partitions.setter
    def partitions(self, partitions):
        """Sets the partitions of this JobTaskSpec.

        How many partitions/tasks will this task be submitted as.  # noqa: E501

        :param partitions: The partitions of this JobTaskSpec.  # noqa: E501
        :type partitions: int
        """
        if self.local_vars_configuration.client_side_validation and partitions is None:  # noqa: E501
            raise ValueError("Invalid value for `partitions`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                partitions is not None and partitions < 1):  # noqa: E501
            raise ValueError("Invalid value for `partitions`, must be a value greater than or equal to `1`")  # noqa: E501

        self._partitions = partitions

    @property
    def runtime(self):
        """Gets the runtime of this JobTaskSpec.  # noqa: E501

        Maximum runtime for this task in whole hours.  # noqa: E501

        :return: The runtime of this JobTaskSpec.  # noqa: E501
        :rtype: int
        """
        return self._runtime

    @runtime.setter
    def runtime(self, runtime):
        """Sets the runtime of this JobTaskSpec.

        Maximum runtime for this task in whole hours.  # noqa: E501

        :param runtime: The runtime of this JobTaskSpec.  # noqa: E501
        :type runtime: int
        """
        if self.local_vars_configuration.client_side_validation and runtime is None:  # noqa: E501
            raise ValueError("Invalid value for `runtime`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                runtime is not None and runtime < 1):  # noqa: E501
            raise ValueError("Invalid value for `runtime`, must be a value greater than or equal to `1`")  # noqa: E501

        self._runtime = runtime

    @property
    def task_distribution(self):
        """Gets the task_distribution of this JobTaskSpec.  # noqa: E501

        How should the partitions be distributed on the HPC cluster  # noqa: E501

        :return: The task_distribution of this JobTaskSpec.  # noqa: E501
        :rtype: str
        """
        return self._task_distribution

    @task_distribution.setter
    def task_distribution(self, task_distribution):
        """Sets the task_distribution of this JobTaskSpec.

        How should the partitions be distributed on the HPC cluster  # noqa: E501

        :param task_distribution: The task_distribution of this JobTaskSpec.  # noqa: E501
        :type task_distribution: str
        """
        if self.local_vars_configuration.client_side_validation and task_distribution is None:  # noqa: E501
            raise ValueError("Invalid value for `task_distribution`, must not be `None`")  # noqa: E501
        allowed_values = ["core", "socket", "node", "device"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and task_distribution not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `task_distribution` ({0}), must be one of {1}"  # noqa: E501
                .format(task_distribution, allowed_values)
            )

        self._task_distribution = task_distribution

    @property
    def hyperthreading(self):
        """Gets the hyperthreading of this JobTaskSpec.  # noqa: E501

        Make use of hyperthreaded core where available  # noqa: E501

        :return: The hyperthreading of this JobTaskSpec.  # noqa: E501
        :rtype: bool
        """
        return self._hyperthreading

    @hyperthreading.setter
    def hyperthreading(self, hyperthreading):
        """Sets the hyperthreading of this JobTaskSpec.

        Make use of hyperthreaded core where available  # noqa: E501

        :param hyperthreading: The hyperthreading of this JobTaskSpec.  # noqa: E501
        :type hyperthreading: bool
        """

        self._hyperthreading = hyperthreading

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobTaskSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, JobTaskSpec):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    EPIC API

    REST API for interacting with EPIC (https://epic.zenotech.com) services. <br />                             Please note this API is in BETA and does not yet contain                             all EPIC functionality.  # noqa: E501

    The version of the OpenAPI document: v2
    Contact: support@zenotech.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from epiccore.api.billing_api import BillingApi
from epiccore.api.catalog_api import CatalogApi
from epiccore.api.data_api import DataApi
from epiccore.api.desktop_api import DesktopApi
from epiccore.api.job_api import JobApi
from epiccore.api.jobauth_api import JobauthApi
from epiccore.api.jobstep_api import JobstepApi
from epiccore.api.licenses_api import LicensesApi
from epiccore.api.profile_api import ProfileApi
from epiccore.api.projects_api import ProjectsApi
from epiccore.api.teams_api import TeamsApi

# import ApiClient
from epiccore.api_client import ApiClient
from epiccore.configuration import Configuration
from epiccore.exceptions import OpenApiException
from epiccore.exceptions import ApiTypeError
from epiccore.exceptions import ApiValueError
from epiccore.exceptions import ApiKeyError
from epiccore.exceptions import ApiAttributeError
from epiccore.exceptions import ApiException
# import models into sdk package
from epiccore.models.accelerator_config import AcceleratorConfig
from epiccore.models.ansys_license import AnsysLicense
from epiccore.models.batch_application_details import BatchApplicationDetails
from epiccore.models.batch_application_list import BatchApplicationList
from epiccore.models.batch_application_version_details import BatchApplicationVersionDetails
from epiccore.models.batch_queue_details import BatchQueueDetails
from epiccore.models.budget import Budget
from epiccore.models.cluster_node_config import ClusterNodeConfig
from epiccore.models.cost import Cost
from epiccore.models.cost_threshold import CostThreshold
from epiccore.models.current_spend import CurrentSpend
from epiccore.models.data_spec import DataSpec
from epiccore.models.desktop_instance import DesktopInstance
from epiccore.models.desktop_node_app import DesktopNodeApp
from epiccore.models.desktop_node_app_summary import DesktopNodeAppSummary
from epiccore.models.desktop_node_application_version import DesktopNodeApplicationVersion
from epiccore.models.desktop_node_application_version_summary import DesktopNodeApplicationVersionSummary
from epiccore.models.desktop_node_connection_type import DesktopNodeConnectionType
from epiccore.models.desktop_node_launch_spec import DesktopNodeLaunchSpec
from epiccore.models.desktop_node_quote import DesktopNodeQuote
from epiccore.models.desktop_node_type import DesktopNodeType
from epiccore.models.discount import Discount
from epiccore.models.folder import Folder
from epiccore.models.folder_details import FolderDetails
from epiccore.models.iaas_cost import IaasCost
from epiccore.models.inline_response200 import InlineResponse200
from epiccore.models.inline_response2001 import InlineResponse2001
from epiccore.models.inline_response20010 import InlineResponse20010
from epiccore.models.inline_response2002 import InlineResponse2002
from epiccore.models.inline_response2003 import InlineResponse2003
from epiccore.models.inline_response2004 import InlineResponse2004
from epiccore.models.inline_response2005 import InlineResponse2005
from epiccore.models.inline_response2006 import InlineResponse2006
from epiccore.models.inline_response2007 import InlineResponse2007
from epiccore.models.inline_response2008 import InlineResponse2008
from epiccore.models.inline_response2009 import InlineResponse2009
from epiccore.models.job import Job
from epiccore.models.job_app_options import JobAppOptions
from epiccore.models.job_array_spec import JobArraySpec
from epiccore.models.job_auth import JobAuth
from epiccore.models.job_auth_status import JobAuthStatus
from epiccore.models.job_cluster_spec import JobClusterSpec
from epiccore.models.job_configuration import JobConfiguration
from epiccore.models.job_data_binding import JobDataBinding
from epiccore.models.job_log import JobLog
from epiccore.models.job_quote import JobQuote
from epiccore.models.job_spec import JobSpec
from epiccore.models.job_step import JobStep
from epiccore.models.job_step_details import JobStepDetails
from epiccore.models.job_summary import JobSummary
from epiccore.models.job_task_spec import JobTaskSpec
from epiccore.models.license import License
from epiccore.models.limit import Limit
from epiccore.models.limits import Limits
from epiccore.models.max_limit import MaxLimit
from epiccore.models.monthly_limit import MonthlyLimit
from epiccore.models.price_quote import PriceQuote
from epiccore.models.product_name import ProductName
from epiccore.models.profile_summary import ProfileSummary
from epiccore.models.project import Project
from epiccore.models.project_details import ProjectDetails
from epiccore.models.sla import SLA
from epiccore.models.service_charge import ServiceCharge
from epiccore.models.software_cost import SoftwareCost
from epiccore.models.spend_limit import SpendLimit
from epiccore.models.task_quote import TaskQuote
from epiccore.models.tax import Tax
from epiccore.models.team import Team
from epiccore.models.team_details import TeamDetails
from epiccore.models.team_select import TeamSelect
from epiccore.models.total import Total
from epiccore.models.total1 import Total1
from epiccore.models.user_name import UserName
from epiccore.models.zenotech_license import ZenotechLicense




# coding: utf-8

"""
    EPIC API

    REST API for interacting with EPIC (https://epic.zenotech.com) services. <br />                             Please note this API is in BETA and does not yet contain                             all EPIC functionality.  # noqa: E501

    The version of the OpenAPI document: v2
    Contact: support@zenotech.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from epiccore.configuration import Configuration


class JobStep(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'run_if_previous_step_fails': 'bool',
        'step_name': 'str',
        'node_count': 'int',
        'num_tasks': 'int',
        'tasks_per_node': 'int',
        'threads_per_task': 'int',
        'max_runtime': 'int',
        'status': 'str',
        'exit_code': 'int',
        'start': 'datetime',
        'end': 'datetime',
        'wallclock': 'str'
    }

    attribute_map = {
        'id': 'id',
        'run_if_previous_step_fails': 'run_if_previous_step_fails',
        'step_name': 'step_name',
        'node_count': 'node_count',
        'num_tasks': 'num_tasks',
        'tasks_per_node': 'tasks_per_node',
        'threads_per_task': 'threads_per_task',
        'max_runtime': 'max_runtime',
        'status': 'status',
        'exit_code': 'exit_code',
        'start': 'start',
        'end': 'end',
        'wallclock': 'wallclock'
    }

    def __init__(self, id=None, run_if_previous_step_fails=None, step_name=None, node_count=None, num_tasks=None, tasks_per_node=None, threads_per_task=None, max_runtime=None, status=None, exit_code=None, start=None, end=None, wallclock=None, local_vars_configuration=None):  # noqa: E501
        """JobStep - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._run_if_previous_step_fails = None
        self._step_name = None
        self._node_count = None
        self._num_tasks = None
        self._tasks_per_node = None
        self._threads_per_task = None
        self._max_runtime = None
        self._status = None
        self._exit_code = None
        self._start = None
        self._end = None
        self._wallclock = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if run_if_previous_step_fails is not None:
            self.run_if_previous_step_fails = run_if_previous_step_fails
        self.step_name = step_name
        if node_count is not None:
            self.node_count = node_count
        if num_tasks is not None:
            self.num_tasks = num_tasks
        if tasks_per_node is not None:
            self.tasks_per_node = tasks_per_node
        if threads_per_task is not None:
            self.threads_per_task = threads_per_task
        if max_runtime is not None:
            self.max_runtime = max_runtime
        self.status = status
        self.exit_code = exit_code
        self.start = start
        self.end = end
        self.wallclock = wallclock

    @property
    def id(self):
        """Gets the id of this JobStep.  # noqa: E501

        jobstep id  # noqa: E501

        :return: The id of this JobStep.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this JobStep.

        jobstep id  # noqa: E501

        :param id: The id of this JobStep.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def run_if_previous_step_fails(self):
        """Gets the run_if_previous_step_fails of this JobStep.  # noqa: E501

        Whether this job step will run if the previous step fails  # noqa: E501

        :return: The run_if_previous_step_fails of this JobStep.  # noqa: E501
        :rtype: bool
        """
        return self._run_if_previous_step_fails

    @run_if_previous_step_fails.setter
    def run_if_previous_step_fails(self, run_if_previous_step_fails):
        """Sets the run_if_previous_step_fails of this JobStep.

        Whether this job step will run if the previous step fails  # noqa: E501

        :param run_if_previous_step_fails: The run_if_previous_step_fails of this JobStep.  # noqa: E501
        :type run_if_previous_step_fails: bool
        """

        self._run_if_previous_step_fails = run_if_previous_step_fails

    @property
    def step_name(self):
        """Gets the step_name of this JobStep.  # noqa: E501

        The name of this job step  # noqa: E501

        :return: The step_name of this JobStep.  # noqa: E501
        :rtype: str
        """
        return self._step_name

    @step_name.setter
    def step_name(self, step_name):
        """Sets the step_name of this JobStep.

        The name of this job step  # noqa: E501

        :param step_name: The step_name of this JobStep.  # noqa: E501
        :type step_name: str
        """
        if self.local_vars_configuration.client_side_validation and step_name is None:  # noqa: E501
            raise ValueError("Invalid value for `step_name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                step_name is not None and len(step_name) > 30):
            raise ValueError("Invalid value for `step_name`, length must be less than or equal to `30`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                step_name is not None and len(step_name) < 1):
            raise ValueError("Invalid value for `step_name`, length must be greater than or equal to `1`")  # noqa: E501

        self._step_name = step_name

    @property
    def node_count(self):
        """Gets the node_count of this JobStep.  # noqa: E501

        Number of nodes this job step will run on  # noqa: E501

        :return: The node_count of this JobStep.  # noqa: E501
        :rtype: int
        """
        return self._node_count

    @node_count.setter
    def node_count(self, node_count):
        """Sets the node_count of this JobStep.

        Number of nodes this job step will run on  # noqa: E501

        :param node_count: The node_count of this JobStep.  # noqa: E501
        :type node_count: int
        """
        if (self.local_vars_configuration.client_side_validation and
                node_count is not None and node_count > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `node_count`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                node_count is not None and node_count < 1):  # noqa: E501
            raise ValueError("Invalid value for `node_count`, must be a value greater than or equal to `1`")  # noqa: E501

        self._node_count = node_count

    @property
    def num_tasks(self):
        """Gets the num_tasks of this JobStep.  # noqa: E501

        Number of tasks that will run for this job step  # noqa: E501

        :return: The num_tasks of this JobStep.  # noqa: E501
        :rtype: int
        """
        return self._num_tasks

    @num_tasks.setter
    def num_tasks(self, num_tasks):
        """Sets the num_tasks of this JobStep.

        Number of tasks that will run for this job step  # noqa: E501

        :param num_tasks: The num_tasks of this JobStep.  # noqa: E501
        :type num_tasks: int
        """
        if (self.local_vars_configuration.client_side_validation and
                num_tasks is not None and num_tasks > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `num_tasks`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                num_tasks is not None and num_tasks < 1):  # noqa: E501
            raise ValueError("Invalid value for `num_tasks`, must be a value greater than or equal to `1`")  # noqa: E501

        self._num_tasks = num_tasks

    @property
    def tasks_per_node(self):
        """Gets the tasks_per_node of this JobStep.  # noqa: E501

        Number of tasks that will run on each node  # noqa: E501

        :return: The tasks_per_node of this JobStep.  # noqa: E501
        :rtype: int
        """
        return self._tasks_per_node

    @tasks_per_node.setter
    def tasks_per_node(self, tasks_per_node):
        """Sets the tasks_per_node of this JobStep.

        Number of tasks that will run on each node  # noqa: E501

        :param tasks_per_node: The tasks_per_node of this JobStep.  # noqa: E501
        :type tasks_per_node: int
        """
        if (self.local_vars_configuration.client_side_validation and
                tasks_per_node is not None and tasks_per_node > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `tasks_per_node`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                tasks_per_node is not None and tasks_per_node < 1):  # noqa: E501
            raise ValueError("Invalid value for `tasks_per_node`, must be a value greater than or equal to `1`")  # noqa: E501

        self._tasks_per_node = tasks_per_node

    @property
    def threads_per_task(self):
        """Gets the threads_per_task of this JobStep.  # noqa: E501

        Number of threads assigned to each task  # noqa: E501

        :return: The threads_per_task of this JobStep.  # noqa: E501
        :rtype: int
        """
        return self._threads_per_task

    @threads_per_task.setter
    def threads_per_task(self, threads_per_task):
        """Sets the threads_per_task of this JobStep.

        Number of threads assigned to each task  # noqa: E501

        :param threads_per_task: The threads_per_task of this JobStep.  # noqa: E501
        :type threads_per_task: int
        """
        if (self.local_vars_configuration.client_side_validation and
                threads_per_task is not None and threads_per_task > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `threads_per_task`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                threads_per_task is not None and threads_per_task < 1):  # noqa: E501
            raise ValueError("Invalid value for `threads_per_task`, must be a value greater than or equal to `1`")  # noqa: E501

        self._threads_per_task = threads_per_task

    @property
    def max_runtime(self):
        """Gets the max_runtime of this JobStep.  # noqa: E501

        Maximum runtime in hours that this job step will run for  # noqa: E501

        :return: The max_runtime of this JobStep.  # noqa: E501
        :rtype: int
        """
        return self._max_runtime

    @max_runtime.setter
    def max_runtime(self, max_runtime):
        """Sets the max_runtime of this JobStep.

        Maximum runtime in hours that this job step will run for  # noqa: E501

        :param max_runtime: The max_runtime of this JobStep.  # noqa: E501
        :type max_runtime: int
        """
        if (self.local_vars_configuration.client_side_validation and
                max_runtime is not None and max_runtime > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `max_runtime`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                max_runtime is not None and max_runtime < 1):  # noqa: E501
            raise ValueError("Invalid value for `max_runtime`, must be a value greater than or equal to `1`")  # noqa: E501

        self._max_runtime = max_runtime

    @property
    def status(self):
        """Gets the status of this JobStep.  # noqa: E501

        Status of this jobstep  # noqa: E501

        :return: The status of this JobStep.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this JobStep.

        Status of this jobstep  # noqa: E501

        :param status: The status of this JobStep.  # noqa: E501
        :type status: str
        """
        if (self.local_vars_configuration.client_side_validation and
                status is not None and len(status) > 50):
            raise ValueError("Invalid value for `status`, length must be less than or equal to `50`")  # noqa: E501

        self._status = status

    @property
    def exit_code(self):
        """Gets the exit_code of this JobStep.  # noqa: E501

        Unix exit code for this job step  # noqa: E501

        :return: The exit_code of this JobStep.  # noqa: E501
        :rtype: int
        """
        return self._exit_code

    @exit_code.setter
    def exit_code(self, exit_code):
        """Sets the exit_code of this JobStep.

        Unix exit code for this job step  # noqa: E501

        :param exit_code: The exit_code of this JobStep.  # noqa: E501
        :type exit_code: int
        """
        if (self.local_vars_configuration.client_side_validation and
                exit_code is not None and exit_code > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `exit_code`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                exit_code is not None and exit_code < -2147483648):  # noqa: E501
            raise ValueError("Invalid value for `exit_code`, must be a value greater than or equal to `-2147483648`")  # noqa: E501

        self._exit_code = exit_code

    @property
    def start(self):
        """Gets the start of this JobStep.  # noqa: E501

        Time this job step started running  # noqa: E501

        :return: The start of this JobStep.  # noqa: E501
        :rtype: datetime
        """
        return self._start

    @start.setter
    def start(self, start):
        """Sets the start of this JobStep.

        Time this job step started running  # noqa: E501

        :param start: The start of this JobStep.  # noqa: E501
        :type start: datetime
        """

        self._start = start

    @property
    def end(self):
        """Gets the end of this JobStep.  # noqa: E501

        Time this job step finished running  # noqa: E501

        :return: The end of this JobStep.  # noqa: E501
        :rtype: datetime
        """
        return self._end

    @end.setter
    def end(self, end):
        """Sets the end of this JobStep.

        Time this job step finished running  # noqa: E501

        :param end: The end of this JobStep.  # noqa: E501
        :type end: datetime
        """

        self._end = end

    @property
    def wallclock(self):
        """Gets the wallclock of this JobStep.  # noqa: E501


        :return: The wallclock of this JobStep.  # noqa: E501
        :rtype: str
        """
        return self._wallclock

    @wallclock.setter
    def wallclock(self, wallclock):
        """Sets the wallclock of this JobStep.


        :param wallclock: The wallclock of this JobStep.  # noqa: E501
        :type wallclock: str
        """

        self._wallclock = wallclock

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobStep):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, JobStep):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    EPIC API

    REST API for interacting with EPIC (https://epic.zenotech.com) services. <br />                             Please note this API is in BETA and does not yet contain                             all EPIC functionality.  # noqa: E501

    The version of the OpenAPI document: v2
    Contact: support@zenotech.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from epiccore.configuration import Configuration


class DesktopNodeApp(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'name': 'str',
        'description': 'str',
        'versions': 'list[DesktopNodeApplicationVersion]',
        'image': 'str',
        'connection_types': 'list[DesktopNodeConnectionType]',
        'node_types': 'list[DesktopNodeType]'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'description': 'description',
        'versions': 'versions',
        'image': 'image',
        'connection_types': 'connection_types',
        'node_types': 'node_types'
    }

    def __init__(self, id=None, name=None, description=None, versions=None, image=None, connection_types=None, node_types=None, local_vars_configuration=None):  # noqa: E501
        """DesktopNodeApp - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._description = None
        self._versions = None
        self._image = None
        self._connection_types = None
        self._node_types = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if versions is not None:
            self.versions = versions
        if image is not None:
            self.image = image
        if connection_types is not None:
            self.connection_types = connection_types
        if node_types is not None:
            self.node_types = node_types

    @property
    def id(self):
        """Gets the id of this DesktopNodeApp.  # noqa: E501


        :return: The id of this DesktopNodeApp.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DesktopNodeApp.


        :param id: The id of this DesktopNodeApp.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this DesktopNodeApp.  # noqa: E501

        The name of this application  # noqa: E501

        :return: The name of this DesktopNodeApp.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DesktopNodeApp.

        The name of this application  # noqa: E501

        :param name: The name of this DesktopNodeApp.  # noqa: E501
        :type name: str
        """
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 100):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def description(self):
        """Gets the description of this DesktopNodeApp.  # noqa: E501

        Detailed description of this application  # noqa: E501

        :return: The description of this DesktopNodeApp.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this DesktopNodeApp.

        Detailed description of this application  # noqa: E501

        :param description: The description of this DesktopNodeApp.  # noqa: E501
        :type description: str
        """
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) > 500):
            raise ValueError("Invalid value for `description`, length must be less than or equal to `500`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) < 1):
            raise ValueError("Invalid value for `description`, length must be greater than or equal to `1`")  # noqa: E501

        self._description = description

    @property
    def versions(self):
        """Gets the versions of this DesktopNodeApp.  # noqa: E501

        List of versions for this application  # noqa: E501

        :return: The versions of this DesktopNodeApp.  # noqa: E501
        :rtype: list[DesktopNodeApplicationVersion]
        """
        return self._versions

    @versions.setter
    def versions(self, versions):
        """Sets the versions of this DesktopNodeApp.

        List of versions for this application  # noqa: E501

        :param versions: The versions of this DesktopNodeApp.  # noqa: E501
        :type versions: list[DesktopNodeApplicationVersion]
        """

        self._versions = versions

    @property
    def image(self):
        """Gets the image of this DesktopNodeApp.  # noqa: E501

        URL of image for this application  # noqa: E501

        :return: The image of this DesktopNodeApp.  # noqa: E501
        :rtype: str
        """
        return self._image

    @image.setter
    def image(self, image):
        """Sets the image of this DesktopNodeApp.

        URL of image for this application  # noqa: E501

        :param image: The image of this DesktopNodeApp.  # noqa: E501
        :type image: str
        """
        if (self.local_vars_configuration.client_side_validation and
                image is not None and len(image) < 1):
            raise ValueError("Invalid value for `image`, length must be greater than or equal to `1`")  # noqa: E501

        self._image = image

    @property
    def connection_types(self):
        """Gets the connection_types of this DesktopNodeApp.  # noqa: E501

        List of connection types available for this application  # noqa: E501

        :return: The connection_types of this DesktopNodeApp.  # noqa: E501
        :rtype: list[DesktopNodeConnectionType]
        """
        return self._connection_types

    @connection_types.setter
    def connection_types(self, connection_types):
        """Sets the connection_types of this DesktopNodeApp.

        List of connection types available for this application  # noqa: E501

        :param connection_types: The connection_types of this DesktopNodeApp.  # noqa: E501
        :type connection_types: list[DesktopNodeConnectionType]
        """

        self._connection_types = connection_types

    @property
    def node_types(self):
        """Gets the node_types of this DesktopNodeApp.  # noqa: E501

        List of nodes types available for this application  # noqa: E501

        :return: The node_types of this DesktopNodeApp.  # noqa: E501
        :rtype: list[DesktopNodeType]
        """
        return self._node_types

    @node_types.setter
    def node_types(self, node_types):
        """Sets the node_types of this DesktopNodeApp.

        List of nodes types available for this application  # noqa: E501

        :param node_types: The node_types of this DesktopNodeApp.  # noqa: E501
        :type node_types: list[DesktopNodeType]
        """

        self._node_types = node_types

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DesktopNodeApp):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DesktopNodeApp):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    EPIC API

    REST API for interacting with EPIC (https://epic.zenotech.com) services. <br />                             Please note this API is in BETA and does not yet contain                             all EPIC functionality.  # noqa: E501

    The version of the OpenAPI document: v2
    Contact: support@zenotech.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from epiccore.configuration import Configuration


class AnsysLicense(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'display_name': 'str',
        'flexlm_host': 'str',
        'flexlm_port': 'int',
        'ansysli_host': 'str',
        'ansysli_port': 'int'
    }

    attribute_map = {
        'display_name': 'display_name',
        'flexlm_host': 'flexlm_host',
        'flexlm_port': 'flexlm_port',
        'ansysli_host': 'ansysli_host',
        'ansysli_port': 'ansysli_port'
    }

    def __init__(self, display_name=None, flexlm_host=None, flexlm_port=None, ansysli_host=None, ansysli_port=None, local_vars_configuration=None):  # noqa: E501
        """AnsysLicense - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._display_name = None
        self._flexlm_host = None
        self._flexlm_port = None
        self._ansysli_host = None
        self._ansysli_port = None
        self.discriminator = None

        self.display_name = display_name
        self.flexlm_host = flexlm_host
        if flexlm_port is not None:
            self.flexlm_port = flexlm_port
        self.ansysli_host = ansysli_host
        if ansysli_port is not None:
            self.ansysli_port = ansysli_port

    @property
    def display_name(self):
        """Gets the display_name of this AnsysLicense.  # noqa: E501

        Name to display to user when selecting this license  # noqa: E501

        :return: The display_name of this AnsysLicense.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this AnsysLicense.

        Name to display to user when selecting this license  # noqa: E501

        :param display_name: The display_name of this AnsysLicense.  # noqa: E501
        :type display_name: str
        """
        if self.local_vars_configuration.client_side_validation and display_name is None:  # noqa: E501
            raise ValueError("Invalid value for `display_name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                display_name is not None and len(display_name) < 1):
            raise ValueError("Invalid value for `display_name`, length must be greater than or equal to `1`")  # noqa: E501

        self._display_name = display_name

    @property
    def flexlm_host(self):
        """Gets the flexlm_host of this AnsysLicense.  # noqa: E501

        Hostname or ip address of flexlm host  # noqa: E501

        :return: The flexlm_host of this AnsysLicense.  # noqa: E501
        :rtype: str
        """
        return self._flexlm_host

    @flexlm_host.setter
    def flexlm_host(self, flexlm_host):
        """Sets the flexlm_host of this AnsysLicense.

        Hostname or ip address of flexlm host  # noqa: E501

        :param flexlm_host: The flexlm_host of this AnsysLicense.  # noqa: E501
        :type flexlm_host: str
        """
        if self.local_vars_configuration.client_side_validation and flexlm_host is None:  # noqa: E501
            raise ValueError("Invalid value for `flexlm_host`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                flexlm_host is not None and len(flexlm_host) < 1):
            raise ValueError("Invalid value for `flexlm_host`, length must be greater than or equal to `1`")  # noqa: E501

        self._flexlm_host = flexlm_host

    @property
    def flexlm_port(self):
        """Gets the flexlm_port of this AnsysLicense.  # noqa: E501

        Port number of flexlm host  # noqa: E501

        :return: The flexlm_port of this AnsysLicense.  # noqa: E501
        :rtype: int
        """
        return self._flexlm_port

    @flexlm_port.setter
    def flexlm_port(self, flexlm_port):
        """Sets the flexlm_port of this AnsysLicense.

        Port number of flexlm host  # noqa: E501

        :param flexlm_port: The flexlm_port of this AnsysLicense.  # noqa: E501
        :type flexlm_port: int
        """
        if (self.local_vars_configuration.client_side_validation and
                flexlm_port is not None and flexlm_port > 65535):  # noqa: E501
            raise ValueError("Invalid value for `flexlm_port`, must be a value less than or equal to `65535`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                flexlm_port is not None and flexlm_port < 1024):  # noqa: E501
            raise ValueError("Invalid value for `flexlm_port`, must be a value greater than or equal to `1024`")  # noqa: E501

        self._flexlm_port = flexlm_port

    @property
    def ansysli_host(self):
        """Gets the ansysli_host of this AnsysLicense.  # noqa: E501

        Hostname or ip address of ansys interconnect server  # noqa: E501

        :return: The ansysli_host of this AnsysLicense.  # noqa: E501
        :rtype: str
        """
        return self._ansysli_host

    @ansysli_host.setter
    def ansysli_host(self, ansysli_host):
        """Sets the ansysli_host of this AnsysLicense.

        Hostname or ip address of ansys interconnect server  # noqa: E501

        :param ansysli_host: The ansysli_host of this AnsysLicense.  # noqa: E501
        :type ansysli_host: str
        """
        if self.local_vars_configuration.client_side_validation and ansysli_host is None:  # noqa: E501
            raise ValueError("Invalid value for `ansysli_host`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                ansysli_host is not None and len(ansysli_host) < 1):
            raise ValueError("Invalid value for `ansysli_host`, length must be greater than or equal to `1`")  # noqa: E501

        self._ansysli_host = ansysli_host

    @property
    def ansysli_port(self):
        """Gets the ansysli_port of this AnsysLicense.  # noqa: E501

        Port number of ansys interconnect server  # noqa: E501

        :return: The ansysli_port of this AnsysLicense.  # noqa: E501
        :rtype: int
        """
        return self._ansysli_port

    @ansysli_port.setter
    def ansysli_port(self, ansysli_port):
        """Sets the ansysli_port of this AnsysLicense.

        Port number of ansys interconnect server  # noqa: E501

        :param ansysli_port: The ansysli_port of this AnsysLicense.  # noqa: E501
        :type ansysli_port: int
        """
        if (self.local_vars_configuration.client_side_validation and
                ansysli_port is not None and ansysli_port > 65535):  # noqa: E501
            raise ValueError("Invalid value for `ansysli_port`, must be a value less than or equal to `65535`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                ansysli_port is not None and ansysli_port < 1024):  # noqa: E501
            raise ValueError("Invalid value for `ansysli_port`, must be a value greater than or equal to `1024`")  # noqa: E501

        self._ansysli_port = ansysli_port

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnsysLicense):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AnsysLicense):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    EPIC API

    REST API for interacting with EPIC (https://epic.zenotech.com) services. <br />                             Please note this API is in BETA and does not yet contain                             all EPIC functionality.  # noqa: E501

    The version of the OpenAPI document: v2
    Contact: support@zenotech.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from epiccore.configuration import Configuration


class Limit(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'team': 'Team',
        'budget': 'Budget',
        'project': 'Project',
        'jobauth': 'JobAuth',
        'id': 'int'
    }

    attribute_map = {
        'team': 'team',
        'budget': 'budget',
        'project': 'project',
        'jobauth': 'jobauth',
        'id': 'id'
    }

    def __init__(self, team=None, budget=None, project=None, jobauth=None, id=None, local_vars_configuration=None):  # noqa: E501
        """Limit - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._team = None
        self._budget = None
        self._project = None
        self._jobauth = None
        self._id = None
        self.discriminator = None

        self.team = team
        if budget is not None:
            self.budget = budget
        if project is not None:
            self.project = project
        if jobauth is not None:
            self.jobauth = jobauth
        self.id = id

    @property
    def team(self):
        """Gets the team of this Limit.  # noqa: E501


        :return: The team of this Limit.  # noqa: E501
        :rtype: Team
        """
        return self._team

    @team.setter
    def team(self, team):
        """Sets the team of this Limit.


        :param team: The team of this Limit.  # noqa: E501
        :type team: Team
        """

        self._team = team

    @property
    def budget(self):
        """Gets the budget of this Limit.  # noqa: E501


        :return: The budget of this Limit.  # noqa: E501
        :rtype: Budget
        """
        return self._budget

    @budget.setter
    def budget(self, budget):
        """Sets the budget of this Limit.


        :param budget: The budget of this Limit.  # noqa: E501
        :type budget: Budget
        """

        self._budget = budget

    @property
    def project(self):
        """Gets the project of this Limit.  # noqa: E501


        :return: The project of this Limit.  # noqa: E501
        :rtype: Project
        """
        return self._project

    @project.setter
    def project(self, project):
        """Sets the project of this Limit.


        :param project: The project of this Limit.  # noqa: E501
        :type project: Project
        """

        self._project = project

    @property
    def jobauth(self):
        """Gets the jobauth of this Limit.  # noqa: E501


        :return: The jobauth of this Limit.  # noqa: E501
        :rtype: JobAuth
        """
        return self._jobauth

    @jobauth.setter
    def jobauth(self, jobauth):
        """Sets the jobauth of this Limit.


        :param jobauth: The jobauth of this Limit.  # noqa: E501
        :type jobauth: JobAuth
        """

        self._jobauth = jobauth

    @property
    def id(self):
        """Gets the id of this Limit.  # noqa: E501

        Team id for this limit. -1 signifies the user's limits  # noqa: E501

        :return: The id of this Limit.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Limit.

        Team id for this limit. -1 signifies the user's limits  # noqa: E501

        :param id: The id of this Limit.  # noqa: E501
        :type id: int
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                id is not None and id < -1):  # noqa: E501
            raise ValueError("Invalid value for `id`, must be a value greater than or equal to `-1`")  # noqa: E501

        self._id = id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Limit):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Limit):
            return True

        return self.to_dict() != other.to_dict()
